import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/configurations/brandConfigurations.dart';
import 'package:lori_sdk/data/models/configurations/orderCodeType.dart';
import 'package:lori_sdk/data/models/configurations/whatsapp_configurations.dart';
import 'package:lori_sdk/data/models/order/order.dart';
import 'package:lori_sdk/data/models/trustDefenderConfiguration.dart';
import 'package:lori_sdk/data/models/product/productOrder.dart';

part 'configurations.g.dart';

@JsonSerializable()
class Configurations {
  Configurations();

  bool showUnavailableProducts;
  int minStock;
  int daysIsNewRole;
  String apiVersion;
  bool showSkuSelector;

  @JsonKey(defaultValue: false)
  bool hasDealerCode;

  @JsonKey(defaultValue: false)
  bool showReaderCodeBar;

  @JsonKey(defaultValue: true)
  bool isSinglePrice;

  @JsonKey(defaultValue: false)
  bool enableSDKCybersource;

  @JsonKey(defaultValue: 0.0)
  double displayRadius;

  @JsonKey(defaultValue: false)
  bool isShowSubCategories = false;

  @JsonKey(defaultValue: ProductOrder.none)
  ProductOrder catalogSort;

  @JsonKey(defaultValue: true)
  bool buyWithOneClick;

  String checkoutPaymentAlertText;

  @JsonKey(defaultValue: false)
  bool forceSellerNameAtList;

  @JsonKey(defaultValue: "Code")
  String productDisplayCodeName;

  @JsonKey(defaultValue: false)
  bool enableUserPromotion;

  @JsonKey(defaultValue: false)
  bool enableWhatsappButton;

  String whatsappPhoneNumber;
  String whatsappMessage;

  @JsonKey(defaultValue: OrderCodeType.externalCode)
  OrderCodeType showOrderCodeType;

  @JsonKey(name: 'retailer')
  BrandConfigurations brandConfigurations;

  @JsonKey(name: 'sdkCybersourceConfiguration')
  TrustDefenderConfiguration trustDefenderConfiguration;

  @JsonKey(name: 'sdkClearSaleFingerprint')
  String clearSaleAppKey;

  /// Those variables here are only to help with formatting
  @JsonKey(ignore: true)
  WhatsappConfigurations whatsapp;

  factory Configurations.fromJson(Map<String, dynamic> json) {
    var configurations = _$ConfigurationsFromJson(json);
    // Whatsapp Configurations
    if (configurations.enableWhatsappButton) {
      configurations.whatsapp = WhatsappConfigurations(
        number: configurations.whatsappPhoneNumber,
        message: configurations.whatsappMessage
      );
    }
    return configurations;
  }

  Map<String, dynamic> toJson() => _$ConfigurationsToJson(this);
}
